# Installation

First, make sure you have [created and activated](https://docs.python.org/3/library/venv.html) a Python3.8+ virtual environment.

Then, run
```console
python -m pip install narwhals
```

Then, if you start the Python REPL and see the following:
```python
>>> import narwhals
>>> narwhals.__version__
'0.9.0'
```
then installation worked correctly!
